@@ -9,16 +9,16 @@
 # You should have received a copy of the GNU General Public License along with seacarb; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 "pmix" <-
-function(flag, var1, var2, pCO2s, wf, S=35, T=20, P=0){
+function(flag, var1, var2, pCO2s, wf, S=35, T=20, P=0, Pt=0, Sit=0){
 	sys <- 0
 	if (sys==0) {
 		ws <- 1 * wf
 		wi <- 1 - ws
-		ci <- carb(flag=flag, var1=var1, var2=var2, S=S ,T=T, P=P)
-		cs <- carb(24, var1=pCO2s, var2=ci$ALK, S=S ,T=T, P=P) # carbonate chemistry of high-CO2 component
+		ci <- carb(flag=flag, var1=var1, var2=var2, S=S ,T=T, P=P, Pt=Pt, Sit=Sit)
+		cs <- carb(24, var1=pCO2s, var2=ci$ALK, S=S ,T=T, P=P, Pt=Pt, Sit=Sit) # carbonate chemistry of high-CO2 component
 		alkf <- ci$ALK  # final alkalinity
 		dicf <- (ci$DIC*wi + cs$DIC*ws)/(wi+ws)	# final dic
-		cf <- carb(flag=15, var1=alkf, var2=dicf, S=S ,T=T, P=P)	 # final carbonate chemistry
+		cf <- carb(flag=15, var1=alkf, var2=dicf, S=S ,T=T, P=P, Pt=Pt, Sit=Sit)	 # final carbonate chemistry
 		co <- as.data.frame(c("pmix-closed-initial", rep("pmix-closed-final", nrow(cf)))) # comment column
 		out <- rbind(ci, cf)
 		out <- cbind(co, out)
